package com.archeus.dex.xml.test;

import com.archeus.WordList;

public class TestDexToXMLTimp extends TestDexToXMLGeneric {

	public static String fileName = "C:\\Cache\\java\\WorkspaceTraducator\\DEXToXML\\data\\timp.html";

	/**
	 * definitia de la <code>timp</code> modificata pentru a include si cazul
	 * 'special' de POS:"...S.m. si (rar) n. ..."
	 */
	public static String fileName2 = "C:\\Cache\\java\\WorkspaceTraducator\\DEXToXML\\data\\timp2.html";

	public void testHeadTimp() {
		loadFile(fileName);
		if (res.size() < 1)
			fail("size<1");
		WordList w = res.get(0);
		assertEquals(w.getName(), WordList.Type.HEAD);
		if (w.getList().size() < 1)
			fail("w.size<1");
		assertEquals(w.getList().toString(), "TIMP,");
	}

	/**
	 * <p>
	 * Se va testa ca este determinata corect prima forma de plural
	 * </p>
	 * 
	 * @author ionut
	 * @since Feb 25, 2007 5:32:40 PM
	 */
	public void testPluralTimp() {
		loadFile(fileName);
		if (res.size() < 2)
			fail("size<2");
		WordList w = res.get(1);
		assertEquals(w.getName(), WordList.Type.PLURAL_GROUP);
		assertEquals(w.getList().size(), 0);
		assertEquals(w.getChildren().size(), 2);
		WordList pl = w.getChildren().get(0);
		assertEquals(pl.getType(), WordList.Type.PLURAL);
		assertEquals(pl.getList().toString(), " timpuri,");
		assertEquals(pl.getChildren().size(), 1);
		
		WordList plc = pl.getChildren().get(0);
		assertEquals(plc.getType(), WordList.Type.PLURAL_COMMENT);
		assertEquals(plc.getList().toString(),
		"(II, V, rar IV)");
		
		
		WordList pos = w.getChildren().get(1);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString()," s.n., ");	
		
	}

	/**
	 * <p>
	 * Se va testa ca este determinata corect a doua forma de plural
	 * </p>
	 * 
	 * @author ionut
	 * @since Feb 25, 2007 5:32:40 PM
	 */
	public void testPlural2Timp() {
		loadFile(fileName);
		if (res.size() < 3)
			fail("size<2");
		WordList w = res.get(2);
		assertEquals(w.getName(), WordList.Type.PLURAL_GROUP);
		assertEquals(w.getList().size(), 0);
		assertEquals(w.getChildren().size(), 2);
		WordList pl = w.getChildren().get(0);
		assertEquals(pl.getType(), WordList.Type.PLURAL);
		assertEquals(pl.getList().toString(), " timpi,");		
		WordList plc = pl.getChildren().get(0);
		assertEquals(plc.getType(), WordList.Type.PLURAL_COMMENT);
		assertEquals(plc.getList().toString(),
				"(IV, inv. si II)");
		WordList pos = w.getChildren().get(1);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString()," s.m. ");
	}

	
	/**
	 * <p>
	 * Se va testa ca este determinata corect prima forma de plural
	 * </p>
	 * 
	 * @author ionut
	 * @since Feb 25, 2007 5:32:40 PM
	 */
	public void testTimp2() {
		loadFile(fileName2);
		if (res.size() < 5)
			fail("size<5: " + res.size());
		// head
		WordList h = res.get(0);
		assertEquals(h.getType(), WordList.Type.HEAD);
		assertEquals(h.getList().toString(), "TIMP,");
		// prima forma de plural, cu paranteze
		WordList plg = res.get(1);
		assertEquals(plg.getName(), WordList.Type.PLURAL_GROUP);
		assertEquals(plg.getList().size(), 0);
		assertEquals(plg.getChildren().size(), 2);
		WordList pl = plg.getChildren().get(0); 
		assertEquals(pl.getType(), WordList.Type.PLURAL);
		assertEquals(pl.getChildren().size(), 1);
		assertEquals(pl.getList().toString(), " timpuri,");
		
		WordList plc = pl.getChildren().get(0);
		assertEquals(plc.getType(), WordList.Type.PLURAL_COMMENT);
		assertEquals(plc.getList().toString(), "(II, V, rar IV)");
		// prima parte de vorbire
		WordList pos = plg.getChildren().get(1);
		assertEquals(pos.getName(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), " s.n., ");
		
		
		// a doua forma de plural
		plg = res.get(2);
		assertEquals(plg.getName(), WordList.Type.PLURAL_GROUP);
		assertEquals(plg.getList().size(), 0);
		assertEquals(plg.getChildren().size(), 2);
		pl = plg.getChildren().get(0); 
		assertEquals(pl.getType(), WordList.Type.PLURAL);
		assertEquals(pl.getChildren().size(), 1);
		assertEquals(pl.getList().toString(), " timpi,");
		
		plc = pl.getChildren().get(0);
		assertEquals(plc.getType(), WordList.Type.PLURAL_COMMENT);
		assertEquals(plc.getList().toString(), "(IV, înv. si II)");
		// prima parte de vorbire
		pos = plg.getChildren().get(1);
		assertEquals(pos.getName(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), " s.m., ");
		
		
		
		// a doua forma de plural
		plg = res.get(3);
		assertEquals(plg.getName(), WordList.Type.PLURAL_GROUP);
		assertEquals(plg.getList().size(), 0);
		assertEquals(plg.getChildren().size(), 2);
		pl = plg.getChildren().get(0); 
		assertEquals(pl.getType(), WordList.Type.PLURAL);
		assertEquals(pl.getChildren().size(), 0);
		assertEquals(pl.getList().toString(), "timpi,");
		// prima parte de vorbire
		pos = plg.getChildren().get(1);
		assertEquals(pos.getName(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), " S.m. si (rar) n. ");
	}
	
	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 6:36:12 PM
	 */
	public void testSensuri() {
		loadFile(fileName);
		if (res.size() < 4)
			fail("size<4:" + res.size());
		WordList w = res.get(3);
		assertEquals(w.getName(), WordList.Type.SENSES);
		assertEquals(w.getType(), WordList.Type.SENSES);
		if (w.getChildren().size() != 5) 
			fail("nr sens != 5: " + w.getChildren().size());
	}


	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 6:50:42 PM
	 */
	public void testSens1() {
		int sensNumber = 0;
		loadFile(fileName);
		assertTrue(res.size() >= 4);
		WordList w = res.get(3);
		if (w.getChildren().size() <= sensNumber) 
			fail("nr sensuri < " + sensNumber);
		WordList sens = w.getChildren().get(sensNumber);
		assertEquals(sens.getType(), WordList.Type.SENSE);
		assertEquals(sens.getName(), "I");
		assertEquals(sens.getPos().size(), 1);
		WordList pos = sens.getPos().get(0);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), "S.n. ");
		assertEquals(sens.getChildren().size(), 0);
		assertEquals(sens.getList().size(), 24);
		assertEquals(sens.getList().toString(), " Dimensiune a Universului dupa care se " +
				"ordoneaza succesiunea ireversibila a fenomenelor. ");		
	}
	
	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 6:57:03 PM
	 */
	public void testSens2() {
		int sensNumber = 1;
		loadFile(fileName);
		assertTrue(res.size() >= 4);
		WordList w = res.get(3);
		if (w.getChildren().size() <= sensNumber) 
			fail("nr sensuri < " + sensNumber);
		WordList sens = w.getChildren().get(sensNumber);
		assertEquals(sens.getType(), WordList.Type.SENSE);
		assertEquals(sens.getName(), "II");
		assertEquals(sens.getPos().size(), 1);
		WordList pos = sens.getPos().get(0);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), "S.n. si (inv.) m. ");
		assertEquals(sens.getChildren().size(), 2);
		// 1
		WordList s = sens.getChildren().get(0);
		assertEquals(s.getType(), WordList.Type.SENSE);
		assertEquals(s.getName(), "1");
		assertTrue(s.getList().size() > 10);
		assertEquals(s.getList().get(0).getText(), " ");
		assertEquals(s.getList().get(1).getText(), "Durata");
		// 2
		s = sens.getChildren().get(1);
		assertEquals(s.getType(), WordList.Type.SENSE);
		assertEquals(s.getName(), "2");
		assertTrue(s.getList().size() > 10);
		assertEquals(s.getList().get(0).getText(), " ");
		assertEquals(s.getList().get(1).getText(), "Perioada");
	}
	
	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 10:35:58 PM
	 */
	public void testSens3() {
		int sensNumber = 2;
		loadFile(fileName);
		assertTrue(res.size() >= 4);
		WordList w = res.get(3);
		if (w.getChildren().size() <= sensNumber) 
			fail("nr sensuri < " + sensNumber);
		WordList sens = w.getChildren().get(sensNumber);
		assertEquals(sens.getType(), WordList.Type.SENSE);
		assertEquals(sens.getName(), "III");
		assertEquals(sens.getPos().size(), 1);
		WordList pos = sens.getPos().get(0);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), "S.n. ");
		assertEquals(sens.getChildren().size(), 0);
		// 1
		WordList s = sens;
		assertTrue(s.getList().size() > 10);
		assertEquals(s.getList().get(0).getText(), " ");
		assertEquals(s.getList().get(1).getText(), "Stare");
	}

	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 10:38:34 PM
	 */
	public void testSens4() {
		int sensNumber = 3;
		loadFile(fileName);
		assertTrue(res.size() >= 4);
		WordList w = res.get(3);
		if (w.getChildren().size() <= sensNumber) 
			fail("nr sensuri < " + sensNumber);
		WordList sens = w.getChildren().get(sensNumber);
		assertEquals(sens.getType(), WordList.Type.SENSE);
		assertEquals(sens.getName(), "IV");
		assertEquals(sens.getPos().size(), 1);
		WordList pos = sens.getPos().get(0);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), "S.m. si (rar) n. ");
		assertEquals(sens.getChildren().size(), 0);
		// 1
		WordList s = sens;
		assertTrue(s.getList().size() > 10);
		assertEquals(s.getList().get(0).getText(), " ");
		assertEquals(s.getList().get(1).getText(), "Fiecare");
	}
	

	/**
	 * 
	 * @author ionut
	 * @since Mar 3, 2007 10:40:02 PM
	 */
	public void testSens5() {
		int sensNumber = 4;
		loadFile(fileName);
		assertTrue(res.size() >= 4);
		WordList w = res.get(3);
		if (w.getChildren().size() <= sensNumber) 
			fail("nr sensuri < " + sensNumber);
		WordList sens = w.getChildren().get(sensNumber);
		assertEquals(sens.getType(), WordList.Type.SENSE);
		assertEquals(sens.getName(), "V");
		assertEquals(sens.getPos().size(), 1);
		WordList pos = sens.getPos().get(0);
		assertEquals(pos.getType(), WordList.Type.POS);
		assertEquals(pos.getList().toString(), "S.n. ");
		assertEquals(sens.getChildren().size(), 0);
		// 1
		WordList s = sens;
		assertTrue(s.getList().size() > 10);
		assertEquals(s.getList().get(0).getText(), " ");
		assertEquals(s.getList().get(1).getText(), "Categorie");
	}
}
